@@ -128,6 +128,7 @@ class TokenAuthHttpDownloader(HttpDownloader):
             DownloadResult: Contains information about the result. See the DownloadResult docs for
                  more information.
         """
+        await asyncio.sleep(0.75)
         async with self.session.get(self.url, headers=headers, proxy=self.proxy) as response:
             self.raise_for_status(response)
             to_return = await self._handle_response(response)
@@ -156,7 +157,9 @@ class TokenAuthHttpDownloader(HttpDownloader):
                 "refresh_token": self.token,
             }
             url = self.ansible_auth_url
-            async with self.session.post(url, data=form_payload, raise_for_status=True) as response:
+            async with self.session.post(
+                url, data=form_payload, proxy=self.proxy, raise_for_status=True
+            ) as response:
                 token_data = await response.text()
 
             AUTH_TOKEN = json.loads(token_data)["access_token"]
